# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/mongodb/v1/config/mongodb4_2.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/mongodb/v1/config/mongodb4_2.proto',
  package='yandex.cloud.mdb.mongodb.v1.config',
  syntax='proto3',
  serialized_options=b'\n&yandex.cloud.api.mdb.mongodb.v1.configZNgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1/config;mongodb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3yandex/cloud/mdb/mongodb/v1/config/mongodb4_2.proto\x12\"yandex.cloud.mdb.mongodb.v1.config\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xfb\n\n\x0fMongodConfig4_2\x12L\n\x07storage\x18\x01 \x01(\x0b\x32;.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage\x12\x63\n\x13operation_profiling\x18\x02 \x01(\x0b\x32\x46.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.OperationProfiling\x12H\n\x03net\x18\x03 \x01(\x0b\x32;.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Network\x1a\xa3\x06\n\x07Storage\x12[\n\x0bwired_tiger\x18\x01 \x01(\x0b\x32\x46.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger\x12T\n\x07journal\x18\x02 \x01(\x0b\x32\x43.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.Journal\x1a\x98\x04\n\nWiredTiger\x12j\n\rengine_config\x18\x01 \x01(\x0b\x32S.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.EngineConfig\x12r\n\x11\x63ollection_config\x18\x02 \x01(\x0b\x32W.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.CollectionConfig\x1a\x43\n\x0c\x45ngineConfig\x12\x33\n\rcache_size_gb\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x1a\xe4\x01\n\x10\x43ollectionConfig\x12|\n\x10\x62lock_compressor\x18\x01 \x01(\x0e\x32\x62.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.CollectionConfig.Compressor\"R\n\nCompressor\x12\x1a\n\x16\x43OMPRESSOR_UNSPECIFIED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\n\n\x06SNAPPY\x10\x02\x12\x08\n\x04ZLIB\x10\x03\x12\x08\n\x04ZSTD\x10\x04\x1aJ\n\x07Journal\x12?\n\x0f\x63ommit_interval\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x31-500\x1a\xec\x01\n\x12OperationProfiling\x12Y\n\x04mode\x18\x01 \x01(\x0e\x32K.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.OperationProfiling.Mode\x12>\n\x11slow_op_threshold\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x07\n\x03OFF\x10\x01\x12\x0b\n\x07SLOW_OP\x10\x02\x12\x07\n\x03\x41LL\x10\x03\x1aV\n\x07Network\x12K\n\x18max_incoming_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-16384\"\x8c\x07\n\x11MongoCfgConfig4_2\x12N\n\x07storage\x18\x01 \x01(\x0b\x32=.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Storage\x12\x65\n\x13operation_profiling\x18\x02 \x01(\x0b\x32H.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.OperationProfiling\x12J\n\x03net\x18\x03 \x01(\x0b\x32=.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Network\x1a\xaa\x02\n\x07Storage\x12]\n\x0bwired_tiger\x18\x01 \x01(\x0b\x32H.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Storage.WiredTiger\x1a\xbf\x01\n\nWiredTiger\x12l\n\rengine_config\x18\x01 \x01(\x0b\x32U.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Storage.WiredTiger.EngineConfig\x1a\x43\n\x0c\x45ngineConfig\x12\x33\n\rcache_size_gb\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x1a\xee\x01\n\x12OperationProfiling\x12[\n\x04mode\x18\x01 \x01(\x0e\x32M.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.OperationProfiling.Mode\x12>\n\x11slow_op_threshold\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x07\n\x03OFF\x10\x01\x12\x0b\n\x07SLOW_OP\x10\x02\x12\x07\n\x03\x41LL\x10\x03\x1aV\n\x07Network\x12K\n\x18max_incoming_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-16384\"\xb3\x01\n\x0fMongosConfig4_2\x12H\n\x03net\x18\x01 \x01(\x0b\x32;.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2.Network\x1aV\n\x07Network\x12K\n\x18max_incoming_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-16384\"\xfa\x01\n\x12MongodConfigSet4_2\x12M\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2\x12H\n\x0buser_config\x18\x02 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2\x12K\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2\"\x82\x02\n\x14MongoCfgConfigSet4_2\x12O\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2\x12J\n\x0buser_config\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2\x12M\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2\"\xfa\x01\n\x12MongosConfigSet4_2\x12M\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2\x12H\n\x0buser_config\x18\x02 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2\x12K\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2Bx\n&yandex.cloud.api.mdb.mongodb.v1.configZNgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1/config;mongodbb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])



_MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR = _descriptor.EnumDescriptor(
  name='Compressor',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.CollectionConfig.Compressor',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMPRESSOR_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NONE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SNAPPY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ZLIB', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ZSTD', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1073,
  serialized_end=1155,
)
_sym_db.RegisterEnumDescriptor(_MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR)

_MONGODCONFIG4_2_OPERATIONPROFILING_MODE = _descriptor.EnumDescriptor(
  name='Mode',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.OperationProfiling.Mode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OFF', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SLOW_OP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1411,
  serialized_end=1470,
)
_sym_db.RegisterEnumDescriptor(_MONGODCONFIG4_2_OPERATIONPROFILING_MODE)

_MONGOCFGCONFIG4_2_OPERATIONPROFILING_MODE = _descriptor.EnumDescriptor(
  name='Mode',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.OperationProfiling.Mode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OFF', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SLOW_OP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1411,
  serialized_end=1470,
)
_sym_db.RegisterEnumDescriptor(_MONGOCFGCONFIG4_2_OPERATIONPROFILING_MODE)


_MONGODCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG = _descriptor.Descriptor(
  name='EngineConfig',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.EngineConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cache_size_gb', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.EngineConfig.cache_size_gb', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=857,
  serialized_end=924,
)

_MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG = _descriptor.Descriptor(
  name='CollectionConfig',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.CollectionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_compressor', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.CollectionConfig.block_compressor', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=927,
  serialized_end=1155,
)

_MONGODCONFIG4_2_STORAGE_WIREDTIGER = _descriptor.Descriptor(
  name='WiredTiger',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='engine_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.engine_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collection_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.collection_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGODCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG, _MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=619,
  serialized_end=1155,
)

_MONGODCONFIG4_2_STORAGE_JOURNAL = _descriptor.Descriptor(
  name='Journal',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.Journal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit_interval', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.Journal.commit_interval', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0051-500', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1157,
  serialized_end=1231,
)

_MONGODCONFIG4_2_STORAGE = _descriptor.Descriptor(
  name='Storage',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wired_tiger', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.wired_tiger', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='journal', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.journal', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGODCONFIG4_2_STORAGE_WIREDTIGER, _MONGODCONFIG4_2_STORAGE_JOURNAL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=428,
  serialized_end=1231,
)

_MONGODCONFIG4_2_OPERATIONPROFILING = _descriptor.Descriptor(
  name='OperationProfiling',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.OperationProfiling',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.OperationProfiling.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slow_op_threshold', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.OperationProfiling.slow_op_threshold', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MONGODCONFIG4_2_OPERATIONPROFILING_MODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1234,
  serialized_end=1470,
)

_MONGODCONFIG4_2_NETWORK = _descriptor.Descriptor(
  name='Network',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Network',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_incoming_connections', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Network.max_incoming_connections', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\01010-16384', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1472,
  serialized_end=1558,
)

_MONGODCONFIG4_2 = _descriptor.Descriptor(
  name='MongodConfig4_2',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.storage', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_profiling', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.operation_profiling', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='net', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.net', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGODCONFIG4_2_STORAGE, _MONGODCONFIG4_2_OPERATIONPROFILING, _MONGODCONFIG4_2_NETWORK, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=1558,
)


_MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG = _descriptor.Descriptor(
  name='EngineConfig',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Storage.WiredTiger.EngineConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cache_size_gb', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Storage.WiredTiger.EngineConfig.cache_size_gb', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=857,
  serialized_end=924,
)

_MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER = _descriptor.Descriptor(
  name='WiredTiger',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Storage.WiredTiger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='engine_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Storage.WiredTiger.engine_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1949,
  serialized_end=2140,
)

_MONGOCFGCONFIG4_2_STORAGE = _descriptor.Descriptor(
  name='Storage',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Storage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wired_tiger', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Storage.wired_tiger', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1842,
  serialized_end=2140,
)

_MONGOCFGCONFIG4_2_OPERATIONPROFILING = _descriptor.Descriptor(
  name='OperationProfiling',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.OperationProfiling',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.OperationProfiling.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slow_op_threshold', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.OperationProfiling.slow_op_threshold', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MONGOCFGCONFIG4_2_OPERATIONPROFILING_MODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2143,
  serialized_end=2381,
)

_MONGOCFGCONFIG4_2_NETWORK = _descriptor.Descriptor(
  name='Network',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Network',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_incoming_connections', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Network.max_incoming_connections', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\01010-16384', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1472,
  serialized_end=1558,
)

_MONGOCFGCONFIG4_2 = _descriptor.Descriptor(
  name='MongoCfgConfig4_2',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.storage', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_profiling', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.operation_profiling', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='net', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.net', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGOCFGCONFIG4_2_STORAGE, _MONGOCFGCONFIG4_2_OPERATIONPROFILING, _MONGOCFGCONFIG4_2_NETWORK, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1561,
  serialized_end=2469,
)


_MONGOSCONFIG4_2_NETWORK = _descriptor.Descriptor(
  name='Network',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2.Network',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_incoming_connections', full_name='yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2.Network.max_incoming_connections', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\01010-16384', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1472,
  serialized_end=1558,
)

_MONGOSCONFIG4_2 = _descriptor.Descriptor(
  name='MongosConfig4_2',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='net', full_name='yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2.net', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGOSCONFIG4_2_NETWORK, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2472,
  serialized_end=2651,
)


_MONGODCONFIGSET4_2 = _descriptor.Descriptor(
  name='MongodConfigSet4_2',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet4_2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='effective_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet4_2.effective_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet4_2.user_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet4_2.default_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2654,
  serialized_end=2904,
)


_MONGOCFGCONFIGSET4_2 = _descriptor.Descriptor(
  name='MongoCfgConfigSet4_2',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet4_2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='effective_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet4_2.effective_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet4_2.user_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet4_2.default_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2907,
  serialized_end=3165,
)


_MONGOSCONFIGSET4_2 = _descriptor.Descriptor(
  name='MongosConfigSet4_2',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet4_2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='effective_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet4_2.effective_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet4_2.user_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet4_2.default_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3168,
  serialized_end=3418,
)

_MONGODCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG.fields_by_name['cache_size_gb'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_MONGODCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG.containing_type = _MONGODCONFIG4_2_STORAGE_WIREDTIGER
_MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG.fields_by_name['block_compressor'].enum_type = _MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR
_MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG.containing_type = _MONGODCONFIG4_2_STORAGE_WIREDTIGER
_MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR.containing_type = _MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG
_MONGODCONFIG4_2_STORAGE_WIREDTIGER.fields_by_name['engine_config'].message_type = _MONGODCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG
_MONGODCONFIG4_2_STORAGE_WIREDTIGER.fields_by_name['collection_config'].message_type = _MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG
_MONGODCONFIG4_2_STORAGE_WIREDTIGER.containing_type = _MONGODCONFIG4_2_STORAGE
_MONGODCONFIG4_2_STORAGE_JOURNAL.fields_by_name['commit_interval'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MONGODCONFIG4_2_STORAGE_JOURNAL.containing_type = _MONGODCONFIG4_2_STORAGE
_MONGODCONFIG4_2_STORAGE.fields_by_name['wired_tiger'].message_type = _MONGODCONFIG4_2_STORAGE_WIREDTIGER
_MONGODCONFIG4_2_STORAGE.fields_by_name['journal'].message_type = _MONGODCONFIG4_2_STORAGE_JOURNAL
_MONGODCONFIG4_2_STORAGE.containing_type = _MONGODCONFIG4_2
_MONGODCONFIG4_2_OPERATIONPROFILING.fields_by_name['mode'].enum_type = _MONGODCONFIG4_2_OPERATIONPROFILING_MODE
_MONGODCONFIG4_2_OPERATIONPROFILING.fields_by_name['slow_op_threshold'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MONGODCONFIG4_2_OPERATIONPROFILING.containing_type = _MONGODCONFIG4_2
_MONGODCONFIG4_2_OPERATIONPROFILING_MODE.containing_type = _MONGODCONFIG4_2_OPERATIONPROFILING
_MONGODCONFIG4_2_NETWORK.fields_by_name['max_incoming_connections'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MONGODCONFIG4_2_NETWORK.containing_type = _MONGODCONFIG4_2
_MONGODCONFIG4_2.fields_by_name['storage'].message_type = _MONGODCONFIG4_2_STORAGE
_MONGODCONFIG4_2.fields_by_name['operation_profiling'].message_type = _MONGODCONFIG4_2_OPERATIONPROFILING
_MONGODCONFIG4_2.fields_by_name['net'].message_type = _MONGODCONFIG4_2_NETWORK
_MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG.fields_by_name['cache_size_gb'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG.containing_type = _MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER
_MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER.fields_by_name['engine_config'].message_type = _MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG
_MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER.containing_type = _MONGOCFGCONFIG4_2_STORAGE
_MONGOCFGCONFIG4_2_STORAGE.fields_by_name['wired_tiger'].message_type = _MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER
_MONGOCFGCONFIG4_2_STORAGE.containing_type = _MONGOCFGCONFIG4_2
_MONGOCFGCONFIG4_2_OPERATIONPROFILING.fields_by_name['mode'].enum_type = _MONGOCFGCONFIG4_2_OPERATIONPROFILING_MODE
_MONGOCFGCONFIG4_2_OPERATIONPROFILING.fields_by_name['slow_op_threshold'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MONGOCFGCONFIG4_2_OPERATIONPROFILING.containing_type = _MONGOCFGCONFIG4_2
_MONGOCFGCONFIG4_2_OPERATIONPROFILING_MODE.containing_type = _MONGOCFGCONFIG4_2_OPERATIONPROFILING
_MONGOCFGCONFIG4_2_NETWORK.fields_by_name['max_incoming_connections'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MONGOCFGCONFIG4_2_NETWORK.containing_type = _MONGOCFGCONFIG4_2
_MONGOCFGCONFIG4_2.fields_by_name['storage'].message_type = _MONGOCFGCONFIG4_2_STORAGE
_MONGOCFGCONFIG4_2.fields_by_name['operation_profiling'].message_type = _MONGOCFGCONFIG4_2_OPERATIONPROFILING
_MONGOCFGCONFIG4_2.fields_by_name['net'].message_type = _MONGOCFGCONFIG4_2_NETWORK
_MONGOSCONFIG4_2_NETWORK.fields_by_name['max_incoming_connections'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MONGOSCONFIG4_2_NETWORK.containing_type = _MONGOSCONFIG4_2
_MONGOSCONFIG4_2.fields_by_name['net'].message_type = _MONGOSCONFIG4_2_NETWORK
_MONGODCONFIGSET4_2.fields_by_name['effective_config'].message_type = _MONGODCONFIG4_2
_MONGODCONFIGSET4_2.fields_by_name['user_config'].message_type = _MONGODCONFIG4_2
_MONGODCONFIGSET4_2.fields_by_name['default_config'].message_type = _MONGODCONFIG4_2
_MONGOCFGCONFIGSET4_2.fields_by_name['effective_config'].message_type = _MONGOCFGCONFIG4_2
_MONGOCFGCONFIGSET4_2.fields_by_name['user_config'].message_type = _MONGOCFGCONFIG4_2
_MONGOCFGCONFIGSET4_2.fields_by_name['default_config'].message_type = _MONGOCFGCONFIG4_2
_MONGOSCONFIGSET4_2.fields_by_name['effective_config'].message_type = _MONGOSCONFIG4_2
_MONGOSCONFIGSET4_2.fields_by_name['user_config'].message_type = _MONGOSCONFIG4_2
_MONGOSCONFIGSET4_2.fields_by_name['default_config'].message_type = _MONGOSCONFIG4_2
DESCRIPTOR.message_types_by_name['MongodConfig4_2'] = _MONGODCONFIG4_2
DESCRIPTOR.message_types_by_name['MongoCfgConfig4_2'] = _MONGOCFGCONFIG4_2
DESCRIPTOR.message_types_by_name['MongosConfig4_2'] = _MONGOSCONFIG4_2
DESCRIPTOR.message_types_by_name['MongodConfigSet4_2'] = _MONGODCONFIGSET4_2
DESCRIPTOR.message_types_by_name['MongoCfgConfigSet4_2'] = _MONGOCFGCONFIGSET4_2
DESCRIPTOR.message_types_by_name['MongosConfigSet4_2'] = _MONGOSCONFIGSET4_2
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MongodConfig4_2 = _reflection.GeneratedProtocolMessageType('MongodConfig4_2', (_message.Message,), {

  'Storage' : _reflection.GeneratedProtocolMessageType('Storage', (_message.Message,), {

    'WiredTiger' : _reflection.GeneratedProtocolMessageType('WiredTiger', (_message.Message,), {

      'EngineConfig' : _reflection.GeneratedProtocolMessageType('EngineConfig', (_message.Message,), {
        'DESCRIPTOR' : _MONGODCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG,
        '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
        # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.EngineConfig)
        })
      ,

      'CollectionConfig' : _reflection.GeneratedProtocolMessageType('CollectionConfig', (_message.Message,), {
        'DESCRIPTOR' : _MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG,
        '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
        # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.CollectionConfig)
        })
      ,
      'DESCRIPTOR' : _MONGODCONFIG4_2_STORAGE_WIREDTIGER,
      '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
      # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger)
      })
    ,

    'Journal' : _reflection.GeneratedProtocolMessageType('Journal', (_message.Message,), {
      'DESCRIPTOR' : _MONGODCONFIG4_2_STORAGE_JOURNAL,
      '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
      # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.Journal)
      })
    ,
    'DESCRIPTOR' : _MONGODCONFIG4_2_STORAGE,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage)
    })
  ,

  'OperationProfiling' : _reflection.GeneratedProtocolMessageType('OperationProfiling', (_message.Message,), {
    'DESCRIPTOR' : _MONGODCONFIG4_2_OPERATIONPROFILING,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.OperationProfiling)
    })
  ,

  'Network' : _reflection.GeneratedProtocolMessageType('Network', (_message.Message,), {
    'DESCRIPTOR' : _MONGODCONFIG4_2_NETWORK,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Network)
    })
  ,
  'DESCRIPTOR' : _MONGODCONFIG4_2,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2)
  })
_sym_db.RegisterMessage(MongodConfig4_2)
_sym_db.RegisterMessage(MongodConfig4_2.Storage)
_sym_db.RegisterMessage(MongodConfig4_2.Storage.WiredTiger)
_sym_db.RegisterMessage(MongodConfig4_2.Storage.WiredTiger.EngineConfig)
_sym_db.RegisterMessage(MongodConfig4_2.Storage.WiredTiger.CollectionConfig)
_sym_db.RegisterMessage(MongodConfig4_2.Storage.Journal)
_sym_db.RegisterMessage(MongodConfig4_2.OperationProfiling)
_sym_db.RegisterMessage(MongodConfig4_2.Network)

MongoCfgConfig4_2 = _reflection.GeneratedProtocolMessageType('MongoCfgConfig4_2', (_message.Message,), {

  'Storage' : _reflection.GeneratedProtocolMessageType('Storage', (_message.Message,), {

    'WiredTiger' : _reflection.GeneratedProtocolMessageType('WiredTiger', (_message.Message,), {

      'EngineConfig' : _reflection.GeneratedProtocolMessageType('EngineConfig', (_message.Message,), {
        'DESCRIPTOR' : _MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG,
        '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
        # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Storage.WiredTiger.EngineConfig)
        })
      ,
      'DESCRIPTOR' : _MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER,
      '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
      # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Storage.WiredTiger)
      })
    ,
    'DESCRIPTOR' : _MONGOCFGCONFIG4_2_STORAGE,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Storage)
    })
  ,

  'OperationProfiling' : _reflection.GeneratedProtocolMessageType('OperationProfiling', (_message.Message,), {
    'DESCRIPTOR' : _MONGOCFGCONFIG4_2_OPERATIONPROFILING,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.OperationProfiling)
    })
  ,

  'Network' : _reflection.GeneratedProtocolMessageType('Network', (_message.Message,), {
    'DESCRIPTOR' : _MONGOCFGCONFIG4_2_NETWORK,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Network)
    })
  ,
  'DESCRIPTOR' : _MONGOCFGCONFIG4_2,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2)
  })
_sym_db.RegisterMessage(MongoCfgConfig4_2)
_sym_db.RegisterMessage(MongoCfgConfig4_2.Storage)
_sym_db.RegisterMessage(MongoCfgConfig4_2.Storage.WiredTiger)
_sym_db.RegisterMessage(MongoCfgConfig4_2.Storage.WiredTiger.EngineConfig)
_sym_db.RegisterMessage(MongoCfgConfig4_2.OperationProfiling)
_sym_db.RegisterMessage(MongoCfgConfig4_2.Network)

MongosConfig4_2 = _reflection.GeneratedProtocolMessageType('MongosConfig4_2', (_message.Message,), {

  'Network' : _reflection.GeneratedProtocolMessageType('Network', (_message.Message,), {
    'DESCRIPTOR' : _MONGOSCONFIG4_2_NETWORK,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2.Network)
    })
  ,
  'DESCRIPTOR' : _MONGOSCONFIG4_2,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2)
  })
_sym_db.RegisterMessage(MongosConfig4_2)
_sym_db.RegisterMessage(MongosConfig4_2.Network)

MongodConfigSet4_2 = _reflection.GeneratedProtocolMessageType('MongodConfigSet4_2', (_message.Message,), {
  'DESCRIPTOR' : _MONGODCONFIGSET4_2,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet4_2)
  })
_sym_db.RegisterMessage(MongodConfigSet4_2)

MongoCfgConfigSet4_2 = _reflection.GeneratedProtocolMessageType('MongoCfgConfigSet4_2', (_message.Message,), {
  'DESCRIPTOR' : _MONGOCFGCONFIGSET4_2,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet4_2)
  })
_sym_db.RegisterMessage(MongoCfgConfigSet4_2)

MongosConfigSet4_2 = _reflection.GeneratedProtocolMessageType('MongosConfigSet4_2', (_message.Message,), {
  'DESCRIPTOR' : _MONGOSCONFIGSET4_2,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet4_2)
  })
_sym_db.RegisterMessage(MongosConfigSet4_2)


DESCRIPTOR._options = None
_MONGODCONFIG4_2_STORAGE_JOURNAL.fields_by_name['commit_interval']._options = None
_MONGODCONFIG4_2_OPERATIONPROFILING.fields_by_name['slow_op_threshold']._options = None
_MONGODCONFIG4_2_NETWORK.fields_by_name['max_incoming_connections']._options = None
_MONGOCFGCONFIG4_2_OPERATIONPROFILING.fields_by_name['slow_op_threshold']._options = None
_MONGOCFGCONFIG4_2_NETWORK.fields_by_name['max_incoming_connections']._options = None
_MONGOSCONFIG4_2_NETWORK.fields_by_name['max_incoming_connections']._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.organizationmanager.v1 import organization_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__pb2
from yandex.cloud.organizationmanager.v1 import organization_service_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__service__pb2


class OrganizationServiceStub(object):
    """A set of methods for managing Organization resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.OrganizationService/Get',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__service__pb2.GetOrganizationRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__pb2.Organization.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.OrganizationService/List',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__service__pb2.ListOrganizationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__service__pb2.ListOrganizationsResponse.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.OrganizationService/Update',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__service__pb2.UpdateOrganizationRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListOperations = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.OrganizationService/ListOperations',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__service__pb2.ListOrganizationOperationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__service__pb2.ListOrganizationOperationsResponse.FromString,
                )
        self.ListAccessBindings = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.OrganizationService/ListAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
                )
        self.SetAccessBindings = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.OrganizationService/SetAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.UpdateAccessBindings = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.OrganizationService/UpdateAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )


class OrganizationServiceServicer(object):
    """A set of methods for managing Organization resources.
    """

    def Get(self, request, context):
        """Returns the specified Organization resource.

        To get the list of available Organization resources, make a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of Organization resources.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperations(self, request, context):
        """Lists operations for the specified organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccessBindings(self, request, context):
        """access

        Lists access bindings for the specified organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAccessBindings(self, request, context):
        """Sets access bindings for the specified organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccessBindings(self, request, context):
        """Updates access bindings for the specified organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OrganizationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__service__pb2.GetOrganizationRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__pb2.Organization.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__service__pb2.ListOrganizationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__service__pb2.ListOrganizationsResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__service__pb2.UpdateOrganizationRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__service__pb2.ListOrganizationOperationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__service__pb2.ListOrganizationOperationsResponse.SerializeToString,
            ),
            'ListAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.SerializeToString,
            ),
            'SetAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.organizationmanager.v1.OrganizationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class OrganizationService(object):
    """A set of methods for managing Organization resources.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.organizationmanager.v1.OrganizationService/Get',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__service__pb2.GetOrganizationRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__pb2.Organization.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.organizationmanager.v1.OrganizationService/List',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__service__pb2.ListOrganizationsRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__service__pb2.ListOrganizationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.organizationmanager.v1.OrganizationService/Update',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__service__pb2.UpdateOrganizationRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.organizationmanager.v1.OrganizationService/ListOperations',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__service__pb2.ListOrganizationOperationsRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__service__pb2.ListOrganizationOperationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.organizationmanager.v1.OrganizationService/ListAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.organizationmanager.v1.OrganizationService/SetAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.organizationmanager.v1.OrganizationService/UpdateAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/containerregistry/v1/scanner_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.containerregistry.v1 import scanner_pb2 as yandex_dot_cloud_dot_containerregistry_dot_v1_dot_scanner__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/containerregistry/v1/scanner_service.proto',
  package='yandex.cloud.containerregistry.v1',
  syntax='proto3',
  serialized_options=b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7yandex/cloud/containerregistry/v1/scanner_service.proto\x12!yandex.cloud.containerregistry.v1\x1a yandex/cloud/api/operation.proto\x1a/yandex/cloud/containerregistry/v1/scanner.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1cgoogle/api/annotations.proto\"-\n\x0bScanRequest\x12\x1e\n\x08image_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"&\n\x0cScanMetadata\x12\x16\n\x0escan_result_id\x18\x01 \x01(\t\"<\n\x14GetScanResultRequest\x12$\n\x0escan_result_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"6\n\x18GetLastScanResultRequest\x12\x1a\n\x08image_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"\xdc\x01\n\x16ListScanResultsRequest\x12\x1c\n\x08image_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12!\n\rrepository_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=100B\n\n\x02id\x12\x04\xc0\xc1\x31\x01\"w\n\x17ListScanResultsResponse\x12\x43\n\x0cscan_results\x18\x01 \x03(\x0b\x32-.yandex.cloud.containerregistry.v1.ScanResult\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xb9\x01\n\x1aListVulnerabilitiesRequest\x12$\n\x0escan_result_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x81\x01\n\x1bListVulnerabilitiesResponse\x12I\n\x0fvulnerabilities\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.containerregistry.v1.Vulnerability\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x9b\x07\n\x0eScannerService\x12\xa0\x01\n\x04Scan\x12..yandex.cloud.containerregistry.v1.ScanRequest\x1a!.yandex.cloud.operation.Operation\"E\x82\xd3\xe4\x93\x02!\"\x1c/container-registry/v1/scans:\x01*\xb2\xd2*\x1a\n\x0cScanMetadata\x12\nScanResult\x12\xa4\x01\n\x03Get\x12\x37.yandex.cloud.containerregistry.v1.GetScanResultRequest\x1a-.yandex.cloud.containerregistry.v1.ScanResult\"5\x82\xd3\xe4\x93\x02/\x12-/container-registry/v1/scans/{scan_result_id}\x12\xb6\x01\n\x07GetLast\x12;.yandex.cloud.containerregistry.v1.GetLastScanResultRequest\x1a-.yandex.cloud.containerregistry.v1.ScanResult\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/container-registry/v1/images/{image_id}:lastScanResult\x12\xa3\x01\n\x04List\x12\x39.yandex.cloud.containerregistry.v1.ListScanResultsRequest\x1a:.yandex.cloud.containerregistry.v1.ListScanResultsResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/container-registry/v1/scans\x12\xdf\x01\n\x13ListVulnerabilities\x12=.yandex.cloud.containerregistry.v1.ListVulnerabilitiesRequest\x1a>.yandex.cloud.containerregistry.v1.ListVulnerabilitiesResponse\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/container-registry/v1/scans/{scan_result_id}:listVulnerabilitiesB\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_containerregistry_dot_v1_dot_scanner__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_SCANREQUEST = _descriptor.Descriptor(
  name='ScanRequest',
  full_name='yandex.cloud.containerregistry.v1.ScanRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='image_id', full_name='yandex.cloud.containerregistry.v1.ScanRequest.image_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=278,
  serialized_end=323,
)


_SCANMETADATA = _descriptor.Descriptor(
  name='ScanMetadata',
  full_name='yandex.cloud.containerregistry.v1.ScanMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scan_result_id', full_name='yandex.cloud.containerregistry.v1.ScanMetadata.scan_result_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=325,
  serialized_end=363,
)


_GETSCANRESULTREQUEST = _descriptor.Descriptor(
  name='GetScanResultRequest',
  full_name='yandex.cloud.containerregistry.v1.GetScanResultRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scan_result_id', full_name='yandex.cloud.containerregistry.v1.GetScanResultRequest.scan_result_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=365,
  serialized_end=425,
)


_GETLASTSCANRESULTREQUEST = _descriptor.Descriptor(
  name='GetLastScanResultRequest',
  full_name='yandex.cloud.containerregistry.v1.GetLastScanResultRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='image_id', full_name='yandex.cloud.containerregistry.v1.GetLastScanResultRequest.image_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=427,
  serialized_end=481,
)


_LISTSCANRESULTSREQUEST = _descriptor.Descriptor(
  name='ListScanResultsRequest',
  full_name='yandex.cloud.containerregistry.v1.ListScanResultsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='image_id', full_name='yandex.cloud.containerregistry.v1.ListScanResultsRequest.image_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repository_id', full_name='yandex.cloud.containerregistry.v1.ListScanResultsRequest.repository_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.containerregistry.v1.ListScanResultsRequest.page_size', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.containerregistry.v1.ListScanResultsRequest.page_token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.containerregistry.v1.ListScanResultsRequest.filter', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by', full_name='yandex.cloud.containerregistry.v1.ListScanResultsRequest.order_by', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='id', full_name='yandex.cloud.containerregistry.v1.ListScanResultsRequest.id',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=484,
  serialized_end=704,
)


_LISTSCANRESULTSRESPONSE = _descriptor.Descriptor(
  name='ListScanResultsResponse',
  full_name='yandex.cloud.containerregistry.v1.ListScanResultsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scan_results', full_name='yandex.cloud.containerregistry.v1.ListScanResultsResponse.scan_results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.containerregistry.v1.ListScanResultsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=706,
  serialized_end=825,
)


_LISTVULNERABILITIESREQUEST = _descriptor.Descriptor(
  name='ListVulnerabilitiesRequest',
  full_name='yandex.cloud.containerregistry.v1.ListVulnerabilitiesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scan_result_id', full_name='yandex.cloud.containerregistry.v1.ListVulnerabilitiesRequest.scan_result_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.containerregistry.v1.ListVulnerabilitiesRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.containerregistry.v1.ListVulnerabilitiesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.containerregistry.v1.ListVulnerabilitiesRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by', full_name='yandex.cloud.containerregistry.v1.ListVulnerabilitiesRequest.order_by', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=828,
  serialized_end=1013,
)


_LISTVULNERABILITIESRESPONSE = _descriptor.Descriptor(
  name='ListVulnerabilitiesResponse',
  full_name='yandex.cloud.containerregistry.v1.ListVulnerabilitiesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vulnerabilities', full_name='yandex.cloud.containerregistry.v1.ListVulnerabilitiesResponse.vulnerabilities', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.containerregistry.v1.ListVulnerabilitiesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1016,
  serialized_end=1145,
)

_LISTSCANRESULTSREQUEST.oneofs_by_name['id'].fields.append(
  _LISTSCANRESULTSREQUEST.fields_by_name['image_id'])
_LISTSCANRESULTSREQUEST.fields_by_name['image_id'].containing_oneof = _LISTSCANRESULTSREQUEST.oneofs_by_name['id']
_LISTSCANRESULTSREQUEST.oneofs_by_name['id'].fields.append(
  _LISTSCANRESULTSREQUEST.fields_by_name['repository_id'])
_LISTSCANRESULTSREQUEST.fields_by_name['repository_id'].containing_oneof = _LISTSCANRESULTSREQUEST.oneofs_by_name['id']
_LISTSCANRESULTSRESPONSE.fields_by_name['scan_results'].message_type = yandex_dot_cloud_dot_containerregistry_dot_v1_dot_scanner__pb2._SCANRESULT
_LISTVULNERABILITIESRESPONSE.fields_by_name['vulnerabilities'].message_type = yandex_dot_cloud_dot_containerregistry_dot_v1_dot_scanner__pb2._VULNERABILITY
DESCRIPTOR.message_types_by_name['ScanRequest'] = _SCANREQUEST
DESCRIPTOR.message_types_by_name['ScanMetadata'] = _SCANMETADATA
DESCRIPTOR.message_types_by_name['GetScanResultRequest'] = _GETSCANRESULTREQUEST
DESCRIPTOR.message_types_by_name['GetLastScanResultRequest'] = _GETLASTSCANRESULTREQUEST
DESCRIPTOR.message_types_by_name['ListScanResultsRequest'] = _LISTSCANRESULTSREQUEST
DESCRIPTOR.message_types_by_name['ListScanResultsResponse'] = _LISTSCANRESULTSRESPONSE
DESCRIPTOR.message_types_by_name['ListVulnerabilitiesRequest'] = _LISTVULNERABILITIESREQUEST
DESCRIPTOR.message_types_by_name['ListVulnerabilitiesResponse'] = _LISTVULNERABILITIESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ScanRequest = _reflection.GeneratedProtocolMessageType('ScanRequest', (_message.Message,), {
  'DESCRIPTOR' : _SCANREQUEST,
  '__module__' : 'yandex.cloud.containerregistry.v1.scanner_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.ScanRequest)
  })
_sym_db.RegisterMessage(ScanRequest)

ScanMetadata = _reflection.GeneratedProtocolMessageType('ScanMetadata', (_message.Message,), {
  'DESCRIPTOR' : _SCANMETADATA,
  '__module__' : 'yandex.cloud.containerregistry.v1.scanner_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.ScanMetadata)
  })
_sym_db.RegisterMessage(ScanMetadata)

GetScanResultRequest = _reflection.GeneratedProtocolMessageType('GetScanResultRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSCANRESULTREQUEST,
  '__module__' : 'yandex.cloud.containerregistry.v1.scanner_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.GetScanResultRequest)
  })
_sym_db.RegisterMessage(GetScanResultRequest)

GetLastScanResultRequest = _reflection.GeneratedProtocolMessageType('GetLastScanResultRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLASTSCANRESULTREQUEST,
  '__module__' : 'yandex.cloud.containerregistry.v1.scanner_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.GetLastScanResultRequest)
  })
_sym_db.RegisterMessage(GetLastScanResultRequest)

ListScanResultsRequest = _reflection.GeneratedProtocolMessageType('ListScanResultsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSCANRESULTSREQUEST,
  '__module__' : 'yandex.cloud.containerregistry.v1.scanner_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.ListScanResultsRequest)
  })
_sym_db.RegisterMessage(ListScanResultsRequest)

ListScanResultsResponse = _reflection.GeneratedProtocolMessageType('ListScanResultsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSCANRESULTSRESPONSE,
  '__module__' : 'yandex.cloud.containerregistry.v1.scanner_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.ListScanResultsResponse)
  })
_sym_db.RegisterMessage(ListScanResultsResponse)

ListVulnerabilitiesRequest = _reflection.GeneratedProtocolMessageType('ListVulnerabilitiesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTVULNERABILITIESREQUEST,
  '__module__' : 'yandex.cloud.containerregistry.v1.scanner_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.ListVulnerabilitiesRequest)
  })
_sym_db.RegisterMessage(ListVulnerabilitiesRequest)

ListVulnerabilitiesResponse = _reflection.GeneratedProtocolMessageType('ListVulnerabilitiesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVULNERABILITIESRESPONSE,
  '__module__' : 'yandex.cloud.containerregistry.v1.scanner_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.ListVulnerabilitiesResponse)
  })
_sym_db.RegisterMessage(ListVulnerabilitiesResponse)


DESCRIPTOR._options = None
_SCANREQUEST.fields_by_name['image_id']._options = None
_GETSCANRESULTREQUEST.fields_by_name['scan_result_id']._options = None
_GETLASTSCANRESULTREQUEST.fields_by_name['image_id']._options = None
_LISTSCANRESULTSREQUEST.oneofs_by_name['id']._options = None
_LISTSCANRESULTSREQUEST.fields_by_name['image_id']._options = None
_LISTSCANRESULTSREQUEST.fields_by_name['repository_id']._options = None
_LISTSCANRESULTSREQUEST.fields_by_name['page_size']._options = None
_LISTSCANRESULTSREQUEST.fields_by_name['page_token']._options = None
_LISTSCANRESULTSREQUEST.fields_by_name['filter']._options = None
_LISTSCANRESULTSREQUEST.fields_by_name['order_by']._options = None
_LISTVULNERABILITIESREQUEST.fields_by_name['scan_result_id']._options = None
_LISTVULNERABILITIESREQUEST.fields_by_name['page_size']._options = None
_LISTVULNERABILITIESREQUEST.fields_by_name['page_token']._options = None
_LISTVULNERABILITIESREQUEST.fields_by_name['filter']._options = None
_LISTVULNERABILITIESREQUEST.fields_by_name['order_by']._options = None

_SCANNERSERVICE = _descriptor.ServiceDescriptor(
  name='ScannerService',
  full_name='yandex.cloud.containerregistry.v1.ScannerService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1148,
  serialized_end=2071,
  methods=[
  _descriptor.MethodDescriptor(
    name='Scan',
    full_name='yandex.cloud.containerregistry.v1.ScannerService.Scan',
    index=0,
    containing_service=None,
    input_type=_SCANREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002!\"\034/container-registry/v1/scans:\001*\262\322*\032\n\014ScanMetadata\022\nScanResult',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.containerregistry.v1.ScannerService.Get',
    index=1,
    containing_service=None,
    input_type=_GETSCANRESULTREQUEST,
    output_type=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_scanner__pb2._SCANRESULT,
    serialized_options=b'\202\323\344\223\002/\022-/container-registry/v1/scans/{scan_result_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetLast',
    full_name='yandex.cloud.containerregistry.v1.ScannerService.GetLast',
    index=2,
    containing_service=None,
    input_type=_GETLASTSCANRESULTREQUEST,
    output_type=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_scanner__pb2._SCANRESULT,
    serialized_options=b'\202\323\344\223\0029\0227/container-registry/v1/images/{image_id}:lastScanResult',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.containerregistry.v1.ScannerService.List',
    index=3,
    containing_service=None,
    input_type=_LISTSCANRESULTSREQUEST,
    output_type=_LISTSCANRESULTSRESPONSE,
    serialized_options=b'\202\323\344\223\002\036\022\034/container-registry/v1/scans',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListVulnerabilities',
    full_name='yandex.cloud.containerregistry.v1.ScannerService.ListVulnerabilities',
    index=4,
    containing_service=None,
    input_type=_LISTVULNERABILITIESREQUEST,
    output_type=_LISTVULNERABILITIESRESPONSE,
    serialized_options=b'\202\323\344\223\002C\022A/container-registry/v1/scans/{scan_result_id}:listVulnerabilities',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SCANNERSERVICE)

DESCRIPTOR.services_by_name['ScannerService'] = _SCANNERSERVICE

# @@protoc_insertion_point(module_scope)
